program dmmnorm(input,output);
{ compute norm of the linearized contraction DM }
const
  hdim=13;
  edim=27;
  lmax=29;
  pdeg=100;
  vdim=150;

%include 'types.h';

var
  cov,beta2,sigma,rho,tau,st: scalar;
  vkappa,vunit,v0,v1,v2,v3: vector;
  m: matrix;

%include 'reps.i';
%include 'scalar.i';
%include 'vector.i';
%include 'linear.i';
%include 'hiemaps.i';

begin { dmmnorm }
  sinit;
  sread('rho.s',rho);
  sread('beta2.s',beta2);
  sread('cov.s',cov);
  sread('sigma.s',sigma);
  sread('tau.s',tau);
  writeln;

  writeln('dmmnorm: warming up');
  vread('nhood.v',rho,v1);
  vread('approx.v',rho,v2);
  vsum(v1,v2,v0);                    { bound on the set V }
  vball(sone,rho,vunit);                      { unit ball }
  vconvinit(cov,rho,vkappa);          { since vdim is new }
  writeln;

  writeln('dmmnorm: apply 1st part of DM to unit ball');
  dmm1(v0,vunit,v1);
  writeln;

  writeln('dmmnorm: apply 2nd part of DM to unit ball');
  mread('m.m',m);
  dmm2(v0,vunit,v2);
  writeln;

  writeln('dmmnorm: apply 3rd part of DM to unit ball');
  dmm3(v0,vunit,v3);
  writeln;

  writeln('dmmnorm: compute norm of DM');
  vsum(v1,v2,v0);
  vsum(v0,v3,v1);
  vnorm(v1,rho,st);
  writeln('dmmnorm: bound on norm =',rst(st.u));
  if slt(st,sone) then writeln('dmmnorm: ok')
  else writeln('dmmnorm: error - norm not less than 1');

  sdone('dmmnorm');
end { dmmnorm }.

