program initial(input,output);
{ compute RG parameters and convert approx.t to approx.v }
const
  hdim=130;
  edim=261;
  vdim=1001;
  lmax=0;
  rho_val='1.0E+1';

%include 'types.h';

var
  cov,beta2,sigma,rho,tau: scalar;
  st1,st2: scalar;
  v: vector;

%include 'reps.i';
%include 'scalar.i';
%include 'sfun.i';
%include 'vector.i';

procedure vtread(f: string; var v: vector);
{ reads polynomial v (with sharp coeffs) from file named f }
var
  i,n: integer;
  s: longstring;
  t: text;
begin { vtread }
  write('(vtread ',trim(f)); flush(output);
  vzero(v);
  reset(t,f);
  readln(t,n);
  if n>=vdim then begin
    writeln('vtread: warning - truncated polynomial');
    n:=vdim-1;
  end;
  for i:=0 to n do begin
    readln(t,s);
    ssset(s,v[i]);
  end;
  write(')');
end { vtread };

begin { initial }
  sinit;

  writeln('initial: read and rewrite approx fixed point');
  vtread('approx.t',v);
  vwrite('approx.v',v);
  writeln;

  writeln('initial: computing beta2');
  slnhalf(st1);
  ismult(5,st1);
  isdiv(3,st1);
  sexp(st1,beta2);                          { beta2 = 2^(-5/3) }

  writeln('initial: computing cov, sigma, tau');
  sdiff(sone,beta2,st1);
  squot(st1,beta2,st2);
  cov:=st2;
  isdiv(2,cov);                    { cov = (1-beta2)/(2*beta2) }
  ssset(rho_val,rho);                          { rho = rho_val }
  ssum(rho,st2,sigma);                     { sigma = rho+2*cov }
  tau:=sigma;
  ismult(2,tau);                               { tau = 2*sigma }

  swrite('rho.s',rho);
  swrite('beta2.s',beta2);
  swrite('cov.s',cov);
  swrite('sigma.s',sigma);
  swrite('tau.s',tau);
  writeln;

  sdone('initial');
end { initial }.

